@@ -45,7 +45,7 @@ CLICK_CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 TG_COMMANDS=[
     'init', 'validate', 'validate-inputs', 'plan', 'apply',
-    'destroy', 'info', 'output', 'show'
+    'destroy', 'info', 'output', 'show',
     ]
 STAGES=['global', 'sbx', 'dev', 'qas', 'run', 'tst', 'acc', 'prd']
 class DefaultGroup(click.Group):
