@@ -50,7 +50,7 @@ class Printer():
 
     def warning(self, msg):
         msg = msg.strip() if isinstance(msg, str) else msg
-        click.secho('\n' + msg + '\n', fg="yellow", bold=True, file=sys.stderr)
+        click.secho(msg, fg="yellow", bold=True, file=sys.stderr)
 
     def error(self, msg):
         msg = msg.strip() if isinstance(msg, str) else msg
@@ -358,8 +358,6 @@ class TgWrap():
         cmd = re.sub(' +', ' ', cmd)
         self.printer.verbose(f'Full command to execute:\n$ {cmd}')
 
-        # cmd = 'echo hello world' # just testing
-
         if dry_run:
             self.printer.warning(f'In dry run mode, no real actions are executed!!')
         else:
@@ -390,7 +388,7 @@ class TgWrap():
         # first run a 'show' and write output to file
         cmd = self.construct_command(
             command='show',
-            exclude_external_dependencies=exclude_external_dependencies,
+            exclude_external_dependencies=True,
             debug=False,
             terragrunt_args=terragrunt_args,
             )
@@ -412,6 +410,7 @@ class TgWrap():
             for line in f:
                 split_line = line.split(self.SEPARATOR)
                 project = split_line[0]
+                print(project)
                 plan_file = split_line[1]
 
                 self.printer.header(f"Analyse project: {project}")
@@ -426,10 +425,13 @@ class TgWrap():
                         for rc in d['resource_changes']:
                             # check if we do have actual changes
                             actions = rc['change']['actions']
-                            if len(actions) == 1 and actions[0] == 'no-op':
+                            if len(actions) == 1 and (actions[0] == 'no-op' or actions[0] == 'read'):
                                 pass # ignore, just an state change
+                            elif 'delete' in actions:
+                                self.printer.warning(f'- {rc["address"]}: {", ".join(actions)}')
+                                changes = True
                             else:
-                                self.printer.normal(f'- {rc["address"]}: {",".join(actions)}')
+                                self.printer.normal(f'- {rc["address"]}: {", ".join(actions)}')
                                 changes = True
 
                         if not changes:
